marktools.DirectedMark
======================

.. abjad-lineage:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark

.. autoclass:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.attach
   :noindex:

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__delattr__
   :noindex:

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__ge__
   :noindex:

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__gt__
   :noindex:

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__le__
   :noindex:

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__lt__
   :noindex:

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark.__repr__
   :noindex:
